==> jsonscript-test-0.1.0.tgz: package/index.js <==
'use strict';

var glob = require('glob');
var path = require('path');
var assert = require('assert');

module.exports = jsonScriptTest;


function jsonScriptTest(jsInterpreters, opts) {
  skipOrOnly(opts, describe)(opts.description || 'JSON schema tests', function() {
    if (opts.timeout) this.timeout(opts.timeout);
    for (var suiteName in opts.suites)
      addTests(suiteName, opts.suites[suiteName]);
  });


  function addTests(suiteName, testsPath) {
    describe(suiteName, function() {
      var files = getTestFiles(testsPath);

      files.forEach(function (file) {
        var filter = {
          skip: getFileFilter(file, 'skip'),
          only: getFileFilter(file, 'only')
        }

        skipOrOnly(filter, describe)(file.name, function() {
          var testDir = path.dirname(file.path);
          var testSuite = require(file.path);

          testSuite.forEach(function (testSet) {
            skipOrOnly(testSet, describe)(testSet.description, function() {
              testSet.tests.forEach(function (test) {
                skipOrOnly(test, it)(test.description, function() {
                  return Array.isArray(jsInterpreters)
                          ? Promise.all(jsInterpreters.map(doTest))
                          : doTest(jsInterpreters);
                });

                function doTest(js) {
                  var data = test.data === undefined ? testSet.data : test.data;
                  var script = test.script === undefined ? testSet.script : test.script;

                  return js.evaluate(script, data)
                  .then(testResult, testException);

                  function testResult(res) {
                    if (test.result) {
                      var method = typeof res == 'object' ? 'deepStrictEqual' : 'strictEqual';
                      try { assert[method](res, test.result); }
                      catch(e) { throw e; }
                    } else {
                      throw new Error('should have failed');
                    }


                    // var passed = valid === test.valid;
                    // if (!passed && opts.log !== false)
                    //   console.log('result:', valid, '\nexpected: ', test.valid, '\nerrors:', validator.errors);
                    // if (valid) assert(!errors || errors.length == 0);
                    // else assert(errors.length > 0);

                    // suiteHooks(passed, valid, errors);
                    // assert.equal(valid, test.valid);
                  }

                  function testException(err) {
                    if (test.result) {
                      throw err;
                    } else {
                      try { assert.equal(err.message, test.error); }
                      catch(e) { throw e; }
                    }

                    // var passed = err.message == test.error;
                    // if (!passed && opts.log !== false)
                    //   console.log('error:', err.message,
                    //     '\nexpected: ',
                    //     test.valid ? 'valid'
                    //       : test.valid === false ? 'invalid'
                    //       : 'error ' + test.error);

                    // suiteHooks(passed);
                    // assert.equal(err.message, test.error);
                  }

                  function suiteHooks(passed, valid, errors) {
                    var result = {
                      passed: passed,
                      validator: validator,
                      schema: schema,
                      data: data,
                      valid: valid,
                      expected: test.valid,
                      expectedError: test.error,
                      errors: errors
                    };

                    if (opts.afterEach) opts.afterEach(result);
                    if (opts.afterError && !passed) opts.afterError(result);
                  }
                }
              });
            });
          });
        });
      });
    });

    function getFileFilter(file, property) {
      var filter = opts[property];
      return Array.isArray(filter) && filter.indexOf(file.name) >= 0;
    }
  }


  function skipOrOnly(filter, func) {
    return filter.only === true ? func.only : filter.skip === true ? func.skip : func;
  }


  function getTestFiles(testsPath) {
    var files = glob.sync(testsPath, { cwd: opts.cwd });
    return files.map(function (file) {
      var match = file.match(/(\w+\/)\w+\.json/)
      var folder = match ? match[1] : '';
      if (opts.hideFolder && folder == opts.hideFolder) folder = '';
      return {
        path: path.join(opts.cwd, file),
        name: folder + path.basename(file, '.json')
      };
    });
  }
}

==> jsonscript-test-0.2.0.tgz: package/index.js <==
'use strict';

var glob = require('glob');
var path = require('path');
var assert = require('assert');
var Ajv = require('ajv');

module.exports = jsonScriptTest;

var ajv = Ajv({ allErrors: true });
ajv.addSchema(require('jsonscript/schema/schema.json'));
var validate = ajv.compile(require('jsonscript-test-suite/test_suite_schema.json'));


function jsonScriptTest(jsInterpreters, opts) {
  skipOrOnly(opts, describe)(opts.description || 'JSONScript tests', function() {
    if (opts.timeout) this.timeout(opts.timeout);
    for (var suiteName in opts.suites)
      addTests(suiteName, opts.suites[suiteName]);
  });


  function addTests(suiteName, testsPath) {
    describe(suiteName, function() {
      var files = getTestFiles(testsPath);

      files.forEach(function (file) {
        var filter = {
          skip: getFileFilter(file, 'skip'),
          only: getFileFilter(file, 'only')
        };

        skipOrOnly(filter, describe)(file.name, function() {
          var testDir = path.dirname(file.path);
          var testSuite = require(file.path);

          var valid = validate(testSuite);
          if (!valid) console.error('Error validating', file.name, '\nErrors:\n', validate.errors);
          assert(valid);


          testSuite.forEach(function (testSet) {
            skipOrOnly(testSet, describe)(testSet.description, function() {
              testSet.tests.forEach(function (test) {
                skipOrOnly(test, it)(test.description, function() {
                  return Array.isArray(jsInterpreters)
                          ? Promise.all(jsInterpreters.map(doTest))
                          : doTest(jsInterpreters);
                });

                function doTest(js) {
                  var data = test.data === undefined ? testSet.data : test.data;
                  var script = test.script === undefined ? testSet.script : test.script;

                  return js.evaluate(script, data)
                  .then(testResult, testException);

                  function testResult(res) {
                    if (test.result !== undefined) {
                      var method = typeof res == 'object' && res !== null
                                    ? 'deepStrictEqual'
                                    : 'strictEqual';
                      try {
                        assert[method](res, test.result);
                        suiteHooks(true, res);
                      } catch(e) {
                        suiteHooks(false, res);
                        throw e;
                      }
                    } else {
                      suiteHooks(false, res);
                      throw new Error('should have failed');
                    }
                  }

                  function testException(err) {
                    if (test.result !== undefined) {
                      suiteHooks(false, undefined, err);
                      throw err;
                    } else {
                      try {
                        if (test.error !== true)
                          assert.equal(err.message, test.error);
                        suiteHooks(true, undefined, err);
                      } catch(e) {
                        suiteHooks(false, undefined, err);
                        throw e;
                      }
                    }
                  }

                  function suiteHooks(passed, result, error) {
                    var result = {
                      passed: passed,
                      jsInterpreter: js,
                      script: script,
                      data: data,
                      test: test,
                      result: result,
                      error: error
                    };

                    if (opts.afterEach) opts.afterEach(result);
                    if (opts.afterError && !passed) opts.afterError(result);
                  }
                }
              });
            });
          });
        });
      });
    });

    function getFileFilter(file, property) {
      var filter = opts[property];
      return Array.isArray(filter) && filter.indexOf(file.name) >= 0;
    }
  }


  function skipOrOnly(filter, func) {
    return filter.only === true ? func.only : filter.skip === true ? func.skip : func;
  }


  function getTestFiles(testsPath) {
    var files = glob.sync(testsPath, { cwd: opts.cwd });
    return files.map(function (file) {
      var match = file.match(/(\w+\/)\w+\.json/)
      var folder = match ? match[1] : '';
      if (opts.hideFolder && folder == opts.hideFolder) folder = '';
      return {
        path: path.join(opts.cwd, file),
        name: folder + path.basename(file, '.json')
      };
    });
  }
}
